@@ -14,9 +14,15 @@
 # limitations under the License.
 
 
+# CAM签名/鉴权错误。
+AUTHFAILURE = 'AuthFailure'
+
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
+# 鉴权失败。
+FAILEDOPERATION_AUTHFAIL = 'FailedOperation.AuthFail'
+
 # 员工已实名。
 FAILEDOPERATION_STAFFALREADYVERIFY = 'FailedOperation.StaffAlreadyVerify'
 
@@ -32,6 +38,9 @@ INTERNALERROR_DB = 'InternalError.Db'
 # 数据库连接出错。
 INTERNALERROR_DBCONNECTION = 'InternalError.DbConnection'
 
+# 数据库新增记录出错。
+INTERNALERROR_DBINSERT = 'InternalError.DbInsert'
+
 # 数据库读取失败。
 INTERNALERROR_DBREAD = 'InternalError.DbRead'
 
@@ -47,6 +56,9 @@ INTERNALERROR_ENCRYPTION = 'InternalError.Encryption'
 # 生成唯一ID错误。
 INTERNALERROR_GENERATEID = 'InternalError.GenerateId'
 
+# 序列化错误。
+INTERNALERROR_SERIALIZE = 'InternalError.Serialize'
+
 # 系统错误。
 INTERNALERROR_SYSTEM = 'InternalError.System'
 
@@ -101,6 +113,9 @@ RESOURCENOTFOUND = 'ResourceNotFound'
 # 应用号不存在。
 RESOURCENOTFOUND_APPLICATION = 'ResourceNotFound.Application'
 
+# 未找到对应流程。
+RESOURCENOTFOUND_FLOW = 'ResourceNotFound.Flow'
+
 # 机构不存在。
 RESOURCENOTFOUND_ORGANIZATION = 'ResourceNotFound.Organization'
 
